@@ -35,7 +35,7 @@ def getCoursesTaken(html):
                 term = html_text[i+5]
             taken = False
             for course in courses:
-                if course.name == name:
+                if course.name == name and course.term == term:
                     taken = True
             if not taken:
             	courses.append(Course(name, term))
